Sophie

Sophie

distrib > Mandriva > 2009.0 > x86_64 > media > main-testing-src > by-pkgid > af5bc481fc2907347d21c48d391ebd07 > files > 11

metisse-0.4.0-1.rc4.14mdv2009.0.src.rpm

--- metisse-0.4.0-rc4/fvwm-insitu/fvwm/ewmh.c	2008-11-18 18:13:17.000000000 +0100
+++ ../SOURCES/metisse-0.4.0/fvwm-insitu/fvwm/ewmh.c	2008-10-21 14:26:14.000000000 +0200
@@ -672,6 +672,7 @@ void EWMH_SetWMState(FvwmWindow *fw, Boo
 
 /*** kde system tray ***/
 /* #define DEBUG_KST */
+
 static
 void add_kst_item(Window w)
 {
@@ -1463,7 +1464,48 @@ int ewmh_HandleDock(EWMH_CMD_ARGS)
 			style->change_mask.use_layer = 1;
 		}
 	}
-	/* no title ? MWM hints should be used by the app but ... */
+	/* no title/border? MWM hints should be used by the app but ... */
+
+	/* No border */
+	SSET_BORDER_WIDTH(*style, 0);
+	style->flags.has_border_width = 1;
+	style->flag_mask.has_border_width = 1;
+	style->change_mask.has_border_width = 1;
+
+	SSET_HANDLE_WIDTH(*style, 0);
+	style->flags.has_handle_width = 1;
+	style->flag_mask.has_handle_width = 1;
+	style->change_mask.has_handle_width = 1;
+
+	/* NoTitle */
+	style->flags.has_no_title = 1;
+	style->flag_mask.has_no_title = 1;
+	style->change_mask.has_no_title = 1;
+
+	/* NeverFocus ??? */
+	FPS_LENIENT(S_FOCUS_POLICY(SCF(*style)), 0);
+	FPS_LENIENT(S_FOCUS_POLICY(SCM(*style)), 1);
+	FPS_LENIENT(S_FOCUS_POLICY(SCC(*style)), 1);
+
+	FPS_FOCUS_ENTER(S_FOCUS_POLICY(SCF(*style)), 0);
+	FPS_UNFOCUS_LEAVE(S_FOCUS_POLICY(SCF(*style)), 0);
+	FPS_FOCUS_CLICK_CLIENT(S_FOCUS_POLICY(SCF(*style)), 0);
+	FPS_FOCUS_CLICK_DECOR(S_FOCUS_POLICY(SCF(*style)), 0);
+	FPS_FOCUS_CLICK_ICON(S_FOCUS_POLICY(SCF(*style)), 0);
+	FPS_FOCUS_BY_FUNCTION(S_FOCUS_POLICY(SCF(*style)), 0);
+
+	FPS_FOCUS_ENTER(S_FOCUS_POLICY(SCM(*style)), 1);
+	FPS_FOCUS_ENTER(S_FOCUS_POLICY(SCC(*style)), 1);
+	FPS_UNFOCUS_LEAVE(S_FOCUS_POLICY(SCM(*style)), 1);
+	FPS_UNFOCUS_LEAVE(S_FOCUS_POLICY(SCC(*style)), 1);
+	FPS_FOCUS_CLICK_CLIENT(S_FOCUS_POLICY(SCM(*style)), 1);
+	FPS_FOCUS_CLICK_CLIENT(S_FOCUS_POLICY(SCC(*style)), 1);
+	FPS_FOCUS_CLICK_DECOR(S_FOCUS_POLICY(SCM(*style)), 1);
+	FPS_FOCUS_CLICK_DECOR(S_FOCUS_POLICY(SCC(*style)), 1);
+	FPS_FOCUS_CLICK_ICON(S_FOCUS_POLICY(SCM(*style)), 1);
+	FPS_FOCUS_CLICK_ICON(S_FOCUS_POLICY(SCC(*style)), 1);
+	FPS_FOCUS_BY_FUNCTION(S_FOCUS_POLICY(SCM(*style)), 1);
+	FPS_FOCUS_BY_FUNCTION(S_FOCUS_POLICY(SCC(*style)), 1);
 
 	return 1;
 }
@@ -1564,7 +1606,7 @@ int ewmh_HandleSplash(EWMH_CMD_ARGS)
 	FPS_FOCUS_BY_FUNCTION(S_FOCUS_POLICY(SCM(*style)), 1);
 	FPS_FOCUS_BY_FUNCTION(S_FOCUS_POLICY(SCC(*style)), 1);
 
-	return 0; // is 0 the expected value??
+	return 1;
 }
 
 int ewmh_HandleToolBar(EWMH_CMD_ARGS)